Learn R Programming

OmicInt (version 1.1.7)

HK_genes: HK_genes

Description

HK_genes function provides a way to visualise how housekeeping genes changed throughout the conditions under the investigation. Depending on the number of conditions separate plots will be generated. Function requires a path variable to a normalised count data file.

Usage

HK_genes(data, meta)

Arguments

data

Requires a path variable to a data file of normalised scores in CSV format (comma separated); class - string

meta

Requires a path variable to a data file of metadata in CSV format (comma separated); class - string

Value

multiple plots; class - plots

Examples

Run this code
# NOT RUN {
path_to_test_data<- system.file("extdata", "normalised_counts.csv", package="OmicInt")
path_to_meta_data<- system.file("extdata", "meta_data.csv", package="OmicInt")
# basic usage of HK_genes
HK_genes(path_to_test_data,path_to_meta_data)
# }

Run the code above in your browser using DataLab